@@ -6,9 +6,9 @@ import os
 import re
 import sys
 
-import language_check.console_mode
-
-DEFAULT_ENCODING = 'utf-8'
+from . import get_build_date
+from . import get_version
+from . import LanguageTool
 
 
 def parse_args():
@@ -35,8 +35,8 @@ def parse_args():
                         help='print results as XML')
     parser.add_argument('--version', action='version',
                         version='LanguageTool {} ({})'
-                                .format(language_check.get_version(),
-                                        language_check.get_build_date()),
+                                .format(get_version(),
+                                        get_build_date()),
                         help='show LanguageTool version and build date')
     parser.add_argument('-a', '--apply', action='store_true',
                         help='automatically apply suggestions if available')
@@ -80,7 +80,8 @@ def main():
         else:
             encoding = args.encoding or 'utf-8'
 
-        lang_tool = language_check.LanguageTool(motherTongue=args.mother_tongue)
+        lang_tool = LanguageTool(
+            motherTongue=args.mother_tongue)
         guess_language = None
 
         if args.language:
@@ -117,11 +118,16 @@ def main():
             print(lang_tool.correct(text))
         else:
             for match in lang_tool.check(text):
+                rule_id = match.ruleId
+                if match.subId is not None:
+                    rule_id += '[{}]'.format(match.subId)
+
                 replacement_text = ', '.join(match.replacements).strip()
-                print('{}:{}:{}: {}{}'.format(
+                print('{}:{}:{}: {}: {}{}'.format(
                     filename,
                     match.fromy + 1,
                     match.fromx + 1,
+                    rule_id,
                     match.msg,
                     ('; suggestions: ' + replacement_text)
                     if replacement_text else ''))
